<?php 
// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

/**
 * @package BuddyPress Community Stats
 * 
 * Setup the admin
*/


/**
 * Remove About page from WP menu
 *
 * since 2.0
 *
 * Add About page on plugins directory
 * aside activation/deactivation buttons
 * 
 * @params admin_menu, network_admin_menu
*/
function bcs_remove_about_menu() {
	
	remove_submenu_page( 'index.php', 'bp_community_stats_about'   );		
}
    
	if( !is_multisite() ) {
		add_action( 'admin_menu', 'bcs_remove_about_menu', 999 );
	}
	if( is_multisite() ) {
		add_action( 'network_admin_menu', 'bcs_remove_about_menu', 999 );
	}

// calling settings array
function etivite_bp_community_stats_admin_counts() {
	return array( 'members', 'active', 'status', 'blogs', 'groups', 'comments', 'posts' );
}

// conditionnal check for network 
function etivite_bp_community_stats_admin_count_check( $type, $currenttypes ) {

	if ( !is_multisite() && $type == 'blogs' ) {
		echo 'disabled';
		return;
	}

	if ( in_array( $type, $currenttypes) )
		echo 'checked';		
	
	return;
}

 /**
 * Display the Settings screen
 *
*/
function etivite_bp_community_stats_admin() {
	global $bp;

	/* If the form has been submitted and the admin referrer checks out, save the settings */
	if ( isset( $_POST['submit'] ) && check_admin_referer('etivite_bp_community_stats_admin') ) {
	
		if( isset($_POST['ab_community_counts'] ) && !empty($_POST['ab_community_counts']) ) {
			update_option( 'bp_community_stats_display', $_POST['ab_community_counts'] );
		} else {
			update_option( 'bp_community_stats_display', false );
		}
		
		$updated = true;
	}
?>	
	<div class="wrap about-wrap">
		<h2><?php _ex( 'Community Stats Settings', 'settings page title', 'buddy-community-stats' ); ?></h2>

		<?php if ( isset($updated) ) : ?><div id='message' class='updated fade'><p><?php _e( 'Settings Updated.', 'buddy-community-stats' ); ?></p></div><?php endif; ?>

		<form action="<?php echo network_admin_url('/admin.php?page=bp-community-stats-settings'); ?>" name="bp-community-stats-settings-form" id="bp-community-stats-settings-form" method="post">

			<h3><?php _ex( 'Select total counts display for:', 'settings page sub title', 'buddy-community-stats' ); ?></h3>

			<table class="form-table">
				<?php

				$enabledcounts = (array) get_option( 'bp_community_stats_display');
				$totalcounts = etivite_bp_community_stats_admin_counts();

				foreach ($totalcounts as $count) { ?>
					<tr>
						<th><label for="type-<?php echo $count; ?>"><?php echo ucfirst($count); ?></label></th>
						<td><input id="type-<?php echo $count; ?>" type="checkbox" <?php etivite_bp_community_stats_admin_count_check( $count, $enabledcounts ); ?> name="ab_community_counts[]" value="<?php echo $count; ?>" /></td>
						<td><?php 
							// give some description to setting fields
							if($count == 'members')	{ _ex( 'Total site members', 'settings description', 'buddy-community-stats' ); }
							if($count == 'active')	{ _ex( 'Total of most active members', 'settings description', 'buddy-community-stats' ); }
							if($count == 'status')	{ _ex( 'Total of published notices, limited to the past 10 days', 'settings description', 'buddy-community-stats' ); }
							if($count == 'blogs')	{ _ex( 'Total blogs (only available if multisite)', 'settings description', 'buddy-community-stats' ); } 
							if($count == 'groups')	{ _ex( 'Total groups, regardless of their status', 'settings description', 'buddy-community-stats' ); }
							if($count == 'comments'){ _ex( 'Total comments', 'settings description', 'buddy-community-stats' ); }
							if($count == 'posts')	{ _ex( 'Total approved posts', 'settings description', 'buddy-community-stats' ); }
                       ?></td>
					</tr>
				<?php } ?>
			</table>	
			
			<?php wp_nonce_field( 'etivite_bp_community_stats_admin' ); ?>
			
			<p class="submit"><input type="submit" name="submit" value="<?php _e( 'Save Settings', 'buddy-community-stats' ) ?>"/></p>			
			

		
		</form>
		<?php if ( is_network_admin() ) { ?>
			<p class="description"><?php _e( 'Please note: Total Posts and Comments could slowdown your network if you have a large community.', 'buddy-community-stats' ); ?></p> 
		<?php } ?>
        <h3><?php _e( 'Display option', 'buddy-community-stats' ); ?></h3>

		<p><?php _e( 'If you don\'t want to use the front end widget, or if you prefer for example to display Community Stats in one line instead of a list in the footer, you can use the below action hook. Copy/paste it into your child-theme where you want Community Stats to show.', 'buddy-community-stats' ); ?></p>
		<p><code>do_action( 'bcs_do_stats' );</code></p>
		<div class="return-to-dashboard"><a href="<?php bcs_return_about() ?>"><?php _e( 'About BuddyPress Community Stats', 'buddy-community-stats' ); ?></a></div>
	</div>
<?php
}

/**
 * Building a Go to settings button
 * since 2.0
*/
function bcs_return() {
	if ( function_exists( 'bp_core_do_network_admin' ) ) {
			$settings_url = add_query_arg( 'page', 'bp-community-stats-settings', bp_core_do_network_admin() ? network_admin_url( 'admin.php' ) : admin_url( 'admin.php' ) );
		} else {
			$settings_url = add_query_arg( 'page', 'bp-community-stats-settings', is_multisite() ? network_admin_url( 'admin.php' ) : admin_url( 'admin.php' ) );
		}
	echo $settings_url;
}

function bcs_return_about() {
	if ( function_exists( 'bp_core_do_network_admin' ) ) {
			$about_url = add_query_arg( 'page', 'bp_community_stats_about',bp_core_do_network_admin() ? network_admin_url( 'index.php' ) : admin_url( 'index.php' ) );
		} else {
			$about_url = add_query_arg( 'page', 'bp_community_stats_about', is_multisite() ? network_admin_url( 'index.php' ) : admin_url( 'index.php' ) );
		}
	echo $about_url;
}

 /**
 * Display the Welcome screen
 * since 2.0
 * @use display_version() to get the current version of the plugin
 */
function about_screen() { ?>

	<div class="wrap about-wrap">
			
    <h1><?php _ex( 'Welcome on BuddyPress Community Stats', 'Welcome screen title', 'buddy-community-stats' ); ?></h1>
	<div class="about-text"><?php _ex( 'Thank you for using BuddyPress Community Stats', 'Welcome screen welcome msg', 'buddy-community-stats' ); ?>&nbsp;<?php display_version(); ?></div>
	<div class="bcs-badge">&nbsp;</div>

	<h2 class="nav-tab-wrapper">
	<?php echo '<a class="nav-tab nav-tab-active" href="'. bp_get_admin_url( 'index.php?page=bp_community_stats_about' ) .' ">' . esc_html_x( 'Presentation', 'Welcome screen tab title', 'buddy-community-stats' ) . '</a>'; ?>		
	</h2>

	<div class="last-feature">	
		<h4><span class="dashicons dashicons-welcome-view-site"></span> <?php _ex( 'BuddyPress Community Stats at a glance', 'Welcome screen sub title', 'buddy-community-stats' ); ?></h4>
			<p><?php _ex( 'BuddyPress Community Stats display your buddypress community total counts for members, active members, status updates, groups, blogs in Widgets, including a wp-admin dashboard widget. Various filters and templatetags can be used for more customization.', 'Welcome screen', 'buddy-community-stats' ); ?></p>
			
		<div class="featured-image">
			<img src="<?php echo plugins_url( 'admin/images/', dirname(__FILE__) ) .'communitystat-widget.png'; ?>" alt="<?php esc_attr_x( 'The BuddyPress Community Stats widget', 'Welcome screen img alt', 'buddy-community-stats' ); ?>">
		</div>

		<div class="feature-section col two-col">
			<div class="last-feature">
				<h4><span class="dashicons dashicons-chart-line"></span> <?php _ex( 'Widget view', 'Welcome screen sub title', 'buddy-community-stats' ); ?></h4>
				<p><?php _ex( 'The widgets displays up to 7 different counts. On dashbord by default and, if activated, on any widget ready theme. ', 'Welcome screen', 'buddy-community-stats' ); ?></p>
			</div>

			<div>
				<h4><span class="dashicons dashicons-admin-plugins"></span> <?php _ex( 'Plugin admin', 'Welcome screen sub title', 'buddy-community-stats' ); ?></h4>
				<p><?php _ex( 'Each count can be activated/deactivated to display totals coming from BuddyPress components.', 'Welcome screen',  'buddy-community-stats' ); ?></p>

			</div>
		</div>
	</div>

	<div class="last-feature">	
		<h4><i class="icon bcs-buddypress"></i> <?php _ex( 'The BuddyPress Community Stats Story', 'Welcome screen sub title', 'buddy-community-stats' ); ?></h4>

		<div class="last-feature">
			<p><?php _e( 'BuddyPress Community Stats was created by Rich Fuller in 2010 for BuddyPress 1.2.9 and WordPress 3.2 Latest update was released in october 2011 for BuddyPress 1.5.1', 'buddy-community-stats' ); ?></p>
			<p><?php _e( 'The plugin was initially developped to be compatible with at least php 5.2. This version is no more maintained on a majority of hosts since spring 2015. Meantime, bp_default theme and bbPress where built out of BuddyPress and WordPress becames more powerfull then never.', 'buddy-community-stats' ); ?></p>
			<p><?php _e( '5 years after his accession, it was high time to breathe new life and a bit of freshness to this friendly plugin.', 'buddy-community-stats' ); ?></p>
		</div>

		<h4><span class="dashicons dashicons-thumbs-up"></span><?php _ex( 'Updates & improvements', 'Welcome screen sub title', 'buddy-community-stats' ); ?></h4>
			<ul>
			<li><?php _ex( 'add new class', 'Welcome screen - use neutral here', 'buddy-community-stats' ); ?> <code>class etivite_bp_community_stats_Widget</code></li>
			<li><?php _ex( 'add new sql queries and', 'Welcome screen - use neutral here', 'buddy-community-stats' ); ?>&nbsp;<code>wpdb->prepare</code></li>
			<li><?php _ex( 'add new About page', 'Welcome screen - use neutral here', 'buddy-community-stats' ); ?> </li>
			<li><?php _ex( 'add new count for posts and comments for network installs', 'Welcome screen - use neutral here', 'buddy-community-stats' ); ?></li>
			<li><?php _ex( 'add new css & images', 'Welcome screen - use neutral here', 'buddy-community-stats' ); ?></li>
			<li><?php _ex( 'add new context for better translation', 'Welcome screen - use neutral here', 'buddy-community-stats' ); ?></li> 
			<li><?php _ex( 'and some minor other improvements...', 'Welcome screen - use neutral here', 'buddy-community-stats' ); ?></li>
			</ul>
	</div>

	<div class="last-feature">			
		<h4><?php _ex( 'Credits', 'Welcome screen sub title', 'buddy-community-stats' ); ?></h4> 

		<p><?php _e( 'Big up for their bug tracking, advices and encouragements to', 'buddy-community-stats' ) ?>&nbsp;<a href="https://profiles.wordpress.org/henry.wright"><span class="avatar-24"><img class="photo avatar avatar-24" src="//www.gravatar.com/avatar/0da2f1a9340d6af196b870f6c107a248?s=24" alt="Henry Wright"></span></a>
					<a class="web" href="https://profiles.wordpress.org/henry.wright">Henry Wright</a> - <a href="https://profiles.wordpress.org/boonebgorges"><span class="avatar-24"><img class="photo avatar avatar-24" src="//www.gravatar.com/avatar/9cf7c4541a582729a5fc7ae484786c0c?s=24" alt="Boone B. Gorges"></span></a>
					<a class="web" href="https://profiles.wordpress.org/boonebgorges">Boone B. Gorges</a>.</p>
		<p><?php _ex('A great Thank You goes to Rich Fuller', 'Welcome screen', 'buddy-community-stats' ); ?> <a href="https://twitter.com/TheRichFuller target="_blank" title="Twitter account" rel="nofollow">@TheRichFuller</a>.</p>

		<h4><?php _ex( 'Enjoy !', 'Welcome screen', 'buddy-community-stats' ); ?></h4>
		<div class="plugin-author">
			<a class="web" href="http://profiles.wordpress.org/users/danbp/"><span class="avatar-24"><img class="photo avatar avatar-24" src="http://www.gravatar.com/avatar/0deae2e7003027fbf153500cd3fa5501?s=24" alt="danbp"></span>danbp</a>
		</div>
	</div>

	<div class="return-to-dashboard">
		 <a href="<?php bcs_return(); ?>"><?php echo _x( 'Go to Buddy Member Stats settings', 'Welcome screen', 'buddy-community-stats' ); ?></a>
	</div>

</div>

<?php
} 