<?php
/*
Plugin Name: Buddy Community Stats
Plugin URI: http://wordpress.org/extend/plugins/buddypress-community-stats/
Description: Display a basic community stats widget
Author: danbp
License: GNU GENERAL PUBLIC LICENSE 3.0 http://www.gnu.org/licenses/gpl.txt
Version: 2.0.1
Text Domain: buddy-community-stats
Domain Path: /languages
*/

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;


// Only load code that needs to run once BP is loaded and initialized. */
function etivite_bp_community_stats_init() {

    require( dirname( __FILE__ ) . '/bp-community-stats.php' );

	add_action( bp_core_admin_hook(), 'etivite_bp_community_stats_admin_add_admin_menu' );
	
}
add_action( 'bp_include', 'etivite_bp_community_stats_init', 88 );


/**
 * Display version
 *
 * since 2.0
*/
function display_version() {
	$display_version = '2.0.1';
echo $display_version;
}


/**
 * BuddyPress Community Stats
 *
 * add text domain
 * since 2.0
 *
*/
function bcs_domain_i18n() {
	load_plugin_textdomain( 'buddy-community-stats', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
}
add_action( 'plugins_loaded', 'bcs_domain_i18n' );


//add admin_menu page
function etivite_bp_community_stats_admin_add_admin_menu() {
	global $bp;
	
	if ( !is_super_admin() )
		return false;
	
	require ( dirname( __FILE__ ) . '/admin/bp-community-stats-admin.php' );
	require ( dirname( __FILE__ ) . '/admin/bp-community-stats-widget-dashboard.php' );

	//Add the component's administration tab under the "BuddyPress" menu for site administrators
	add_submenu_page( bp_core_do_network_admin() ? 'settings.php' : 'options-general.php', __( 'Community Stats', 'buddy-community-stats' ), __( 'Community Stats', 'buddy-community-stats' ), 'manage_options', 'bp-community-stats-settings', 'etivite_bp_community_stats_admin' );	
	add_submenu_page( 'index.php', __( 'About Community Stats', 'buddy-community-stats' ), __( 'About Community Stats', 'buddy-community-stats' ), 'manage_options', 'bp_community_stats_about', 'about_screen' );
		
	//dashboard widget
	add_action('wp_dashboard_setup', 'etivite_bp_community_stats_dashboard_widget');
}


/**
 * BuddyPress Community Stats
 *
 * since 2.0
 *
 * About link on plugin's directory
 *
 * @params array_push 
*/
function bcs_admin_add_action_link( $links, $file ) {
	if ( 'buddypress-community-stats/bp-community-stats-loader.php' != $file )
		return $links;

	if ( function_exists( 'bp_core_do_network_admin' ) ) {
		$settings_url = add_query_arg( 'page', 'bp-community-stats-settings', bp_core_do_network_admin() ? network_admin_url( 'admin.php' ) : admin_url( 'admin.php' ) );
	} else {
		$settings_url = add_query_arg( 'page', 'bp-community-stats-settings', is_multisite() ? network_admin_url( 'admin.php' ) : admin_url( 'admin.php' ) );
	}

	$settings_link = '<a href="' . $settings_url . '">' . __( 'Settings', 'buddy-community-stats' ) . '</a>';
	$about_link    = '<a href="'. bp_get_admin_url( 'index.php?page=bp_community_stats_about' ) .' ">' . esc_html__( 'About', 'buddy-community-stats' ) . '</a>';

	// here we use array_push to go AFTER activate and delete buttons
	array_push( $links, $settings_link, $about_link );

	return $links;
}
if( ! is_multisite() ) {
	add_filter( 'plugin_action_links', 'bcs_admin_add_action_link', 10, 2 ); 
}
if( is_multisite() ) {
	add_filter( 'network_admin_plugin_action_links', 'bcs_admin_add_action_link', 10, 2 );	
}

/**
 * BuddyPress Community Stats
 *
 * Add backend stylesheet
 *
 * since 2.0
*/
function bcs_enqueue_admin_css() { 
	wp_enqueue_style( 'bcs-style-admin', plugin_dir_url( __FILE__ ) . 'admin/css/bcs-admin.css' );
}
add_action( 'admin_enqueue_scripts', 'bcs_enqueue_admin_css' );


/**
 * BuddyPress Community Stats
 *
 * Enqueue Dashicons style for frontend use 
 *
 * since 2.0
 */
function bcs_frontend_dashicons() {
	wp_enqueue_style( 'dashicons' );
}
add_action( 'wp_enqueue_scripts', 'bcs_frontend_dashicons' );

//widget reference for all
require( dirname( __FILE__ ) . '/bp-community-stats-widget.php' );