<?php
// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

/**
 * BuddyPress Community Stats
 *
 * Member count
*/
function etivite_bp_community_stats_members() {
	echo etivite_bp_community_stats_get_members();
}

	/**
	 * Filter Members 
	 *
	 * since 2.0
	*/
	function etivite_bp_community_stats_get_members() {
	
		$total_count = bp_core_get_total_member_count();
		
		if ( $total_count == 0 ) {
			$content = __( ' No Members', 'buddy-community-stats' );
		} else if ( $total_count == 1 ) {
			$content = '<span class="dashicons dashicons-businessman"></span><span class="community-count">'. $total_count .'</span>&nbsp;' . __( ' member', 'buddy-community-stats' );
		} else {
			$content = '<span class="dashicons dashicons-businessman"></span><span class="community-count">'. $total_count .'</span>&nbsp;' . __( ' members', 'buddy-community-stats' );
		}
		
	return apply_filters( 'etivite_bp_community_stats_get_member_status', $content, $total_count );	
	}


/**
 * BuddyPress Community Stats
 *
 * since 2.0
 *
 * Active member count in past 10 days
*/
function etivite_bp_community_stats_active() {
	echo etivite_bp_community_stats_get_active();
}

	/**
	 * Filter Active members 
	 *
	 * since 2.0
	*/
	function etivite_bp_community_stats_get_active() {
	
		$total_count = etivite_bp_community_stats_active_count();
		
		if ( $total_count == 0 ) {
			$content = __( ' No recent active members', 'buddy-community-stats' );
		} else if ( $total_count == 1 ) {
			$content = '<span class="dashicons dashicons-universal-access"></span><span class="community-count">'. $total_count .'</span>&nbsp;' . __( ' active member', 'buddy-community-stats' );
		} else {
			$content = '<span class="dashicons dashicons-universal-access"></span><span class="community-count">'. $total_count .'</span>&nbsp;' . __( ' active members', 'buddy-community-stats' );
		}
		
	return apply_filters( 'etivite_bp_community_stats_get_status', $content, $total_count );	
	}


	/**
	 * Query Active members
	 *
	 * since 2.0
	*/
	function etivite_bp_community_stats_active_count() {
	global $bp, $wpdb;
	$item_id = null;

	// 10 days (in minutes) * seconds
	$time = date('Y-m-d H:i:s', time() - ( 14400 * 60 ) );  
		
		if ( bp_is_active( 'activity' ) ) :

		// DB query 
		$count = $wpdb->get_var( $wpdb->prepare( "SELECT COUNT(user_id) FROM {$wpdb->prefix}bp_activity 
				WHERE type = 'last_activity'
				AND date_recorded > '$time'
				AND item_id = '%s' ", $item_id ) );
			return $count;

		endif;	
	}


/**
 * BuddyPress Community Stats
 *
 * Updates count in site wide activity
 * Group updates excluded.
*/
function etivite_bp_community_stats_status() {
	echo etivite_bp_community_stats_get_status();
}

	/**
	 * Filter Updates
	 *
	 * since 2.0
	*/
	function etivite_bp_community_stats_get_status() {
	
		$total_count = etivite_bp_community_stats_status_count();
		
		if ( $total_count == 0 ) {
			$content = __( ' No updates', 'buddy-community-stats' );
		} else if ( $total_count == 1 ) {
			$content = '<span class="dashicons dashicons-testimonial"></span><span class="community-count">'. $total_count .'</span>&nbsp;' . __( ' update', 'buddy-community-stats' );
		} else {
			$content = '<span class="dashicons dashicons-testimonial"></span><span class="community-count">'. $total_count .'</span>&nbsp;' . __( ' updates', 'buddy-community-stats' );
		}
		
	return apply_filters( 'etivite_bp_community_stats_get_status', $content, $total_count );	
	}


	/**
	 * Query Updates
	 *
	 * since 2.0
	 *
	*/
	function etivite_bp_community_stats_status_count() {
	global $bp, $wpdb;
	$item_id = null;

		if ( bp_is_active( 'activity' ) ) :

			$count = $wpdb->get_var( $wpdb->prepare( "SELECT COUNT(id) FROM {$wpdb->prefix}bp_activity 
					WHERE type = 'activity_update'
					AND item_id = '%s' ", $item_id ) );	
			return $count;

		endif;
	} 

/**
 * BuddyPress Community Stats
 *
 * Groups count
*/
function etivite_bp_community_stats_groups() {
	echo etivite_bp_community_stats_get_groups();
}

	/**
	 * Filter Groups 
	 *
	 * since 2.0
	*/
	function etivite_bp_community_stats_get_groups() {
		
	if ( bp_is_active( 'groups' ) ) :

		$total_count = groups_get_total_group_count();
		
		if ( $total_count == 0 ) {
			$content = __( ' No groups', 'buddy-community-stats' );
		} else if ( $total_count == 1 ) {
			$content = '<span class="dashicons dashicons-groups"></span><span class="community-count">'. $total_count .'</span>&nbsp;' . __( ' group', 'buddy-community-stats' );
		} else {
			$content = '<span class="dashicons dashicons-groups"></span><span class="community-count">'. $total_count .'</span>&nbsp;' . __( ' groups', 'buddy-community-stats' );
		}
		
	return apply_filters( 'etivite_bp_community_stats_get_groups', $content, $total_count );	

	endif;
	}


/**
 * BuddyPress Community Stats
 *
 * Blogs count 
*/
function etivite_bp_community_stats_blogs() {
	echo etivite_bp_community_stats_get_blogs();
}

	/**
	 * Filter Blogs 
	 *
	 * since 2.0
	*/
	function etivite_bp_community_stats_get_blogs() {

	if ( is_multisite() ) { 
		
		$total_count = bp_blogs_total_blogs();
		
		if ( $total_count == 1 ) {
			$content = '<span class="dashicons dashicons-admin-network"></span><span class="community-count">'. $total_count .'</span>&nbsp;' . __( ' blog', 'buddy-community-stats' );
		} else {
			$content = '<span class="dashicons dashicons-admin-network"></span><span class="community-count">'. $total_count .'</span>&nbsp;' . __( ' blogs', 'buddy-community-stats' );
		}	

		return apply_filters( 'etivite_bp_community_stats_get_blogs', $content, $total_count );	
		}	
	}


/**
 * BuddyPress Community Stats
 *
 * Posts comments count
*/
function etivite_bp_community_stats_comments() {
	echo etivite_bp_community_stats_get_comments();
}


	/**
	 * Filter Posts Comments 
	 *
	 * since 2.0
	*/
	function etivite_bp_community_stats_get_comments() {
		
		$total_count = etivite_bp_community_stats_get_comment_count();
		
		if ( $total_count == 0 ) {
			$content = __( ' No blog comments', 'buddy-community-stats' );
		} else if ( $total_count == 1 ) {
			$content = '<span class="dashicons dashicons-admin-comments"></span><span class="community-count">'. $total_count .'</span>&nbsp;' . __( ' blog comment', 'buddy-community-stats' );
		} else {
			$content = '<span class="dashicons dashicons-admin-comments"></span><span class="community-count">'. $total_count .'</span>&nbsp;' . __( ' blog comments', 'buddy-community-stats' );
		}
		
	return apply_filters( 'etivite_bp_community_stats_get_comments', $content, $total_count );	
	}


	/**
	 * Query Posts Comments 
	 *
	 * since 2.0
	*/
	function etivite_bp_community_stats_get_comment_count() {
	 global $bp, $wpdb;
		// if single install
		if ( !is_multisite() ) {
			$count = wp_count_comments();

			if( isset( $count->approved )){	
				$count = $count->approved;	
			return $count; 
			} 
		}
		// if network install
		if ( is_multisite() ) {		

		$total_site_comments = $wpdb->get_var( $wpdb->prepare( "SELECT COUNT(id) FROM {$wpdb->prefix}bp_activity 
				WHERE type = %s", 'new_blog_comment' ) );
								  
		return $total_site_comments;
		}
	}


/**
 * BuddyPress Community Stats
 *
 * Posts count
*/
function etivite_bp_community_stats_posts() {
	echo etivite_bp_community_stats_get_posts();
}


	/**
	 * Filter Posts 
	 *
	 * since 2.0
	*/
	function etivite_bp_community_stats_get_posts() {
		
		$total_count = etivite_bp_community_stats_get_post_count();
		
		if ( $total_count == 0 ) {
			$content = __( ' No blog posts', 'buddy-community-stats' );
		} else if ( $total_count == 1 ) {
			$content = '<span class="dashicons dashicons-admin-post"></span></span><span class="community-post">'. $total_count .'</span>&nbsp;' . __( ' blog post', 'buddy-community-stats' );
		} else {
			$content = '<span class="dashicons dashicons-admin-post"></span></span><span class="community-post">'. $total_count .'</span>&nbsp;' . __( ' blog posts', 'buddy-community-stats' );
		}
		
	return apply_filters( 'etivite_bp_community_stats_get_posts', $content, $total_count );	
	}


	/**
	 * Query Posts 
	 *
	 * since 2.0
	*/
	function etivite_bp_community_stats_get_post_count() {
	global $bp, $wpdb;

		// if network install
		if( is_multisite() ) {	

		$total_site_posts = $wpdb->get_var( $wpdb->prepare( "SELECT COUNT(id) FROM {$wpdb->prefix}bp_activity 
				WHERE type = %s", 'new_blog_post' ) );
						
			return $total_site_posts;
		}

		// if single install
		if( !is_multisite() ) {

		$count_posts = wp_count_posts('post');
		$published_posts = 0;

		if(isset($count_posts->publish)){
			$published_posts = $count_posts->publish;
		}

		return $published_posts;
		}
	}

/**
 * BuddyPress Community Stats
 * since 2.0
 *
 * Display community stats on one line instead of a list
 *
 * Intended for footer display but can be used elsewhere.
*/


function bcs_stats_footer() { 

	$data = (array) maybe_unserialize( get_option( 'bp_community_stats_display') );

	if ( in_array( 'members', $data ) )
		$counts[] = etivite_bp_community_stats_get_members();
		
	if ( in_array( 'active', $data ) )
		$counts[] = etivite_bp_community_stats_get_active();
		
	if ( in_array( 'status', $data ) )
		$counts[] = etivite_bp_community_stats_get_status();
			
	if ( in_array( 'groups', $data ) )
		$counts[] = etivite_bp_community_stats_get_groups();	
	
	if ( is_multisite() ) {
		if ( in_array( 'blogs', $data ) )
			$counts[] = etivite_bp_community_stats_get_blogs();
	}
	
	if ( in_array( 'posts', $data ) )
		$counts[] = etivite_bp_community_stats_get_posts();

	if ( in_array( 'comments', $data ) )
		$counts[] = etivite_bp_community_stats_get_comments();

	$i = 0;
	$l = count( $counts );
	echo '<div id="bcs-stats-footer">';
	echo apply_filters( 'community_stats_footer', sprintf( __( '%s serving ', 'buddy-community-stats' ), bloginfo('name') ) );
	
	foreach ( (array) $counts as $count) {
		$isLastItem = ( $i == ( $l - 1 ) );
		
		echo $count;
		if (!$isLastItem) 
			echo apply_filters( 'community_stats_footer_spacer', ' &#124;' );
		
		++$i;
	}
	echo '</div>';

}
add_action('bcs_do_stats', 'bcs_stats_footer' );